@@ -4,8 +4,8 @@ from cement import Controller, ex
 
 from banyan.api.service import ServiceAPI
 from banyan.controllers.base import Base
-from banyan.model.service import ServiceInfo, Service
 from banyan.lib.service import DEFAULT_TIMEOUT, DEFAULT_DNS_SERVER, ServiceTest
+from banyan.model.service import ServiceInfo, Service
 
 
 class ServiceController(Controller):
@@ -57,7 +57,7 @@ class ServiceController(Controller):
         ])
     def create(self):
         spec = Base.get_json_input(self.app.pargs.service_spec)
-        service = Service.Schema().load(spec)
+        service: ServiceInfo = Service.Schema().load(spec)
         info = self._client.create(service)
         self.app.render(ServiceInfo.Schema().dump(info), handler='json', indent=2, sort_keys=True)
 
@@ -71,7 +71,7 @@ class ServiceController(Controller):
         ])
     def update(self):
         spec = Base.get_json_input(self.app.pargs.service_spec)
-        service = Service.Schema().load(spec)
+        service: ServiceInfo = Service.Schema().load(spec)
         info = self._client.update(service)
         self.app.render(ServiceInfo.Schema().dump(info), handler='json', indent=2, sort_keys=True)
 
@@ -167,12 +167,14 @@ class ServiceController(Controller):
             (['--timeout'],
              {
                  'type': float,
-                 'help': f'Length of time to wait for backend service to respond, in seconds. (default: {DEFAULT_TIMEOUT})',
+                 'help': 'Length of time to wait for backend service to respond, in seconds. '
+                         f'(default: {DEFAULT_TIMEOUT})',
                  'default': DEFAULT_TIMEOUT
              }),
             (['--external-dns'],
              {
-                 'help': f'Public DNS server to query for service resolution. (default: {DEFAULT_DNS_SERVER})',
+                 'help': 'Public DNS server to query for service resolution. '
+                         f'(default: {DEFAULT_DNS_SERVER})',
                  'default': DEFAULT_DNS_SERVER
              }),
             (['--wildcard'],
@@ -181,7 +183,7 @@ class ServiceController(Controller):
              })
         ])
     def test(self):
-        info: ServiceInfo = self._client[self.app.pargs.service_name]
+        info = self._client[self.app.pargs.service_name]
         harness = ServiceTest(info.service, self.app.client,
                               self.app.pargs.timeout, self.app.pargs.external_dns,
                               self.app.pargs.wildcard)
